@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016 Adrien Vergé
 #
 # This program is free software: you can redistribute it and/or modify
@@ -81,10 +80,7 @@ def get_cosmetic_problems(buffer, conf, filepath):
             self.all_rules = {r.ID for r in rules}
 
         def process_comment(self, comment):
-            try:
-                comment = str(comment)
-            except UnicodeError:
-                return  # this certainly wasn't a yamllint directive comment
+            comment = str(comment)
 
             if re.match(r'^# yamllint disable( rule:\S+)*\s*$', comment):
                 items = comment[18:].rstrip().split(' ')
@@ -110,10 +106,7 @@ def get_cosmetic_problems(buffer, conf, filepath):
 
     class DisableLineDirective(DisableDirective):
         def process_comment(self, comment):
-            try:
-                comment = str(comment)
-            except UnicodeError:
-                return  # this certainly wasn't a yamllint directive comment
+            comment = str(comment)
 
             if re.match(r'^# yamllint disable-line( rule:\S+)*\s*$', comment):
                 items = comment[23:].rstrip().split(' ')
@@ -206,15 +199,11 @@ def _run(buffer, conf, filepath):
                 syntax_error.column <= problem.column):
             yield syntax_error
 
-            # If there is already a yamllint error at the same place, discard
-            # it as it is probably redundant (and maybe it's just a 'warning',
+            # Discard the problem since it is at the same place as the syntax
+            # error and is probably redundant (and maybe it's just a 'warning',
             # in which case the script won't even exit with a failure status).
-            if (syntax_error.line == problem.line and
-                    syntax_error.column == problem.column):
-                syntax_error = None
-                continue
-
             syntax_error = None
+            continue
 
         yield problem
 
@@ -233,7 +222,7 @@ def run(input, conf, filepath=None):
     if conf.is_file_ignored(filepath):
         return ()
 
-    if isinstance(input, (type(b''), type(u''))):  # compat with Python 2 & 3
+    if isinstance(input, (bytes, str)):
         return _run(input, conf, filepath)
     elif hasattr(input, 'read'):  # Python 2's file or Python 3's io.IOBase
         # We need to have everything in memory to parse correctly
